@@ -33,7 +33,7 @@ def _get_openssl_libraries(platform):
         # libssl must come before libcrypto
         # (https://marc.info/?l=openssl-users&m=135361825921871)
         # -lpthread required due to usage of pthread an potential
-        # existance of a static part containing e.g. pthread_atfork
+        # existence of a static part containing e.g. pthread_atfork
         # (https://github.com/pyca/cryptography/issues/5084)
         if sys.platform == "zos":
             return ["ssl", "crypto"]
@@ -70,7 +70,7 @@ def _extra_compile_args(platform):
 
 
 ffi = build_ffi_for_binding(
-    module_name="_openssl",
+    module_name="cryptography.hazmat.bindings._openssl",
     module_prefix="_cffi_src.openssl.",
     modules=[
         # This goes first so we can define some cryptography-wide symbols.
@@ -81,7 +81,6 @@ ffi = build_ffi_for_binding(
         "bignum",
         "bio",
         "cmac",
-        "conf",
         "crypto",
         "dh",
         "dsa",
